.. include:: ../BADGES.rst

Python API Function Summary
===========================

.. autosummary::
    :toctree: _function_autosummary

    swmmtoolbox.swmmtoolbox.about
    swmmtoolbox.swmmtoolbox.catalog
    swmmtoolbox.swmmtoolbox.extract
    swmmtoolbox.swmmtoolbox.listdetail
    swmmtoolbox.swmmtoolbox.listvariables
    swmmtoolbox.swmmtoolbox.stdtoswmm5
